@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,13 +12,9 @@
 #include <QFileDialog>
 #include <QProcess>
 
-EvolutionAddressBook::EvolutionAddressBook()
-{
-}
+EvolutionAddressBook::EvolutionAddressBook() = default;
 
-EvolutionAddressBook::~EvolutionAddressBook()
-{
-}
+EvolutionAddressBook::~EvolutionAddressBook() = default;
 
 void EvolutionAddressBook::exportEvolutionAddressBook()
 {
